@@ -5,6 +5,7 @@
 #include <QFile>
 #include <QFileInfo>
 #include <QMap>
+#include <qurl.h>
 
 #include "account.h"
 #include "post.h"
@@ -75,12 +76,13 @@ Post::Post(Account *parent, QJsonObject obj)
     } else {
         m_repeat = true;
 
-        auto repeat_doc = obj["reblog"].toObject();
-        auto repeat_account_doc = repeat_doc["account"].toObject();
+        auto repeat_account_doc = reblog_obj["account"].toObject();
         auto repeat_acct = repeat_account_doc["acct"].toString();
 
         m_author_identity = m_parent->identityLookup(repeat_acct, repeat_account_doc);
         m_repeat_identity = m_parent->identityLookup(acct, account_doc);
+
+        obj = reblog_obj;
     }
 
     m_subject = obj["spoiler_text"].toString();
@@ -96,19 +98,10 @@ Post::Post(Account *parent, QJsonObject obj)
     m_pinned = obj["pinned"].toBool();
     m_visibility = str_to_vis[obj["visibility"].toString()];
     m_published_at = QDateTime::fromString(obj["created_at"].toString(), Qt::ISODate);
-
-    QJsonArray mentions;
-
-    if (m_repeat) {
-        m_visibility = str_to_vis[reblog_obj["visibility"].toString()];
-        m_replyTargetId = reblog_obj["id"].toString();
-        addAttachments(reblog_obj["media_attachments"].toArray());
-
-        mentions = reblog_obj["mentions"].toArray();
-    } else {
-        addAttachments(obj["media_attachments"].toArray());
-
-        mentions = obj["mentions"].toArray();
+    addAttachments(obj["media_attachments"].toArray());
+    const QJsonArray mentions = obj["mentions"].toArray();
+    if (obj.contains("card") && !obj["card"].toObject().empty()) {
+        setCard(std::make_optional<Card>(obj["card"].toObject()));
     }
 
     for (const auto &m : qAsConst(mentions)) {
@@ -240,6 +233,26 @@ int Notification::id() const
     return m_id;
 }
 
+Account *Notification::account() const
+{
+    return m_account;
+}
+
+Notification::Type Notification::type() const
+{
+    return m_type;
+}
+
+std::shared_ptr<Post> Notification::post() const
+{
+    return m_post;
+}
+
+std::shared_ptr<Identity> Notification::identity() const
+{
+    return m_identity;
+}
+
 QString Post::subject() const
 {
     return m_subject;
@@ -309,3 +322,83 @@ void Post::setVisibility(Visibility visibility)
     m_visibility = visibility;
     Q_EMIT visibilityChanged();
 }
+
+std::optional<Card> Post::card() const
+{
+    return m_card;
+}
+
+void Post::setCard(std::optional<Card> card)
+{
+    m_card = card;
+}
+
+Card::Card(QJsonObject card)
+    : m_card(card)
+{
+}
+
+QString Card::authorName() const
+{
+    return m_card[QLatin1String("author_name")].toString();
+}
+
+QString Card::authorUrl() const
+{
+    return m_card[QLatin1String("author_url")].toString();
+}
+
+QString Card::blurhash() const
+{
+    return m_card[QLatin1String("blurhas")].toString();
+}
+
+QString Card::description() const
+{
+    return m_card[QLatin1String("description")].toString();
+}
+
+QString Card::embedUrl() const
+{
+    return m_card[QLatin1String("embed_url")].toString();
+}
+
+int Card::width() const
+{
+    return m_card[QLatin1String("weight")].toInt();
+}
+
+int Card::height() const
+{
+    return m_card[QLatin1String("height")].toInt();
+}
+
+QString Card::html() const
+{
+    return m_card[QLatin1String("html")].toString();
+}
+
+QString Card::image() const
+{
+    return m_card[QLatin1String("image")].toString();
+}
+
+QString Card::providerName() const
+{
+    return m_card[QLatin1String("provider_name")].toString();
+}
+
+QString Card::providerUrl() const
+{
+    return m_card[QLatin1String("provider_url")].toString();
+}
+
+QString Card::title() const
+{
+    return m_card[QLatin1String("title")].toString();
+}
+
+QUrl Card::url() const
+{
+    return QUrl::fromUserInput(m_card[QLatin1String("url")].toString());
+}
